==> activemq-jms-server-0.8.0.1-sources.jar: org/bluestemsoftware/open/eoa/ext/feature/jms/server/activemq/mgmt/jmx/Connector.java <==
/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.ext.feature.jms.server.activemq.mgmt.jmx;

import org.apache.activemq.broker.jmx.ConnectorViewMBean;
import org.bluestemsoftware.specification.eoa.ext.ExtensionFactoryContext;

public class Connector implements ConnectorMBean {

    private ConnectorViewMBean underlying;
    private ExtensionFactoryContext factoryContext;

    public Connector(ExtensionFactoryContext factoryContext, ConnectorViewMBean underlying) {
        this.factoryContext = factoryContext;
        this.underlying = underlying;
    }

    public long getDequeueCount() {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            return underlying.getDequeueCount();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public long getEnqueueCount() {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            return underlying.getEnqueueCount();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void resetStatistics() {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.resetStatistics();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void start() throws Exception {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.start();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void stop() throws Exception {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.stop();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

}

==> activemq-jms-server-0.8.5.0-sources.jar: org/bluestemsoftware/open/eoa/ext/feature/jms/server/activemq/mgmt/jmx/Connector.java <==
/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.ext.feature.jms.server.activemq.mgmt.jmx;

import org.apache.activemq.broker.jmx.ConnectorViewMBean;
import org.bluestemsoftware.specification.eoa.ext.ExtensionFactoryContext;

public class Connector implements ConnectorMBean {

    private ConnectorViewMBean underlying;
    private ExtensionFactoryContext factoryContext;

    public Connector(ExtensionFactoryContext factoryContext, ConnectorViewMBean underlying) {
        this.factoryContext = factoryContext;
        this.underlying = underlying;
    }

    public void resetStatistics() {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.resetStatistics();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void start() throws Exception {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.start();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void stop() throws Exception {

        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.stop();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void disableStatistics() {
        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.disableStatistics();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public void enableStatistics() {
        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            underlying.enableStatistics();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

    public boolean isStatisticsEnabled() {
        Thread thread = Thread.currentThread();
        ClassLoader cl = thread.getContextClassLoader();
        try {
            thread.setContextClassLoader(factoryContext.getClassLoader());
            return underlying.isStatisticsEnabled();

        } finally {
            thread.setContextClassLoader(cl);
        }
    }

}
